* {
    margin: 0;
    padding: 0;
    border: none;
}
body, table {
    font-family: Helvetica, Arial, sans-serif;
    font-size: 14px;
}
a:link, a:visited {
    text-decoration: none;
}
a:link {
    color: #36c;
}
a:visited {
    color: #333;
}
a:hover {
    text-decoration: underline;
}
#readme {
    padding: 10px 26px;
    border-bottom: 1px solid #eee;
    font-size: 12px;
    color: #333;
    background: #fafafa;
}
#readme pre {
    line-height: 1.2;
}
#readme p, #readme ul, #readme ol,
#readme h1, #readme h2, #readme h3, #readme h4, #readme h5, #readme h6 {
    display: block;
    margin-bottom: 1em;
}
#readme h1, #readme h2, #readme h3, #readme h4, #readme h5, #readme h6 {
    padding: 0;
    color: #456;
    text-align: left;
    font-family: sans-serif;
    font-weight: bolder;
}
#readme pre code {
    display: block;
    padding: 9px;
    margin: 0 -10px 1em;
    border: 1px solid #cde;
    color: #567;
    background: #fff;
}
#readme li {
    margin-left: 2em;
}
#readme blockquote {
    padding: 9px;
    margin: 0 -10px 1em;
    border-left: 1px solid #cde;
}
#readme blockquote :last-child {
    margin-bottom: 0;
}
#readme h1 { font-size: 1.5em; }
#readme h2 { font-size: 1.4em; }
#readme h3 { font-size: 1.3em; }
#readme h4 { font-size: 1.2em; }
#readme h5 { font-size: 1.1em; }
#readme h6 { font-size: 1em; }
.breadcrumb {
    padding: 0;
}
.breadcrumb a {
    margin: 0;
    color: #666;
    font-size: 12px;
}
.breadcrumb .sep {
    color: #bbb;
}
.breadcrumb img {
    vertical-align: middle;
}
.breadcrumb h1 {
    font-size: 12px;
    font-weight: normal;
    padding: 5px;
    background: #f4f4f4;
    border-top: 1px solid #ccc;
}
table {
    border-collapse: collapse;
    width: 100%;
    background: #fff;
}
thead {
    border-bottom: 1px solid #ccc;
}
th {
    font-size: 11px;
    height: 30px;
    background: #ddd;
    background: -webkit-gradient(
    linear,
    left bottom,
    left top,
    color-stop(0, #ddd),
    color-stop(1, #eee)
    );
    background: -moz-linear-gradient(
    center bottom,
    #ddd 0%,
    #eee 100%
    );
}
th a:link, th a:visited {
    margin: 0 10px;
    color: #333;
}
th img {
    position: absolute;
    margin-left: -6px;
}
tbody {
    border: solid #ccc;
    border-width: 1px 0;
}
hr {
    margin: 0;
    border: none;
}
td {
    padding: 5px;
    font-size: 11px;
    color: #333;
    border-left: 1px dashed #eee;
}
td a {
    margin-right: 40px;
    font-size: 14px;
}
td.modified {
    text-align: center;
}
td.size {
    text-align: right;
}
.icon, .name {
    border: none;
}
.icon {
    width: 16px;
    padding-right: 0;
}
.modified {
    width: 120px;
}
.size {
    width: 60px;
}
address {
    padding: 5px;
    font-size: 11px;
    color: #333;
    text-align: right;
}
