__version__ = '0.2.7'
__author__ = "Kirill Klenov <horneds@gmail.com>"
__email__ = "horneds@gmail.com"
__license__ = "GNU LGPL"
__url__ = 'http://github.com/klen/pyserve'


if __name__ == '__main__':
    from .main import main
    main()
